==> xnu-2422.115.4.tar.gz: xnu-2422.115.4/bsd/sys/kern_overrides.h <==
/*
 * Copyright (c) 2013 Apple Computer, Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 * 
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 * 
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 * 
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 * 
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */

#ifndef _SYS_KERN_OVERRIDES_H
#define _SYS_KERN_OVERRIDES_H

#include <sys/cdefs.h>
#include <sys/param.h>
#include <sys/types.h>
#include <stdint.h>

__BEGIN_DECLS

/* System Overrides Flags */
#define SYS_OVERRIDE_IO_THROTTLE	0x1
#define SYS_OVERRIDE_CPU_THROTTLE	0x2

#define SYS_OVERRIDE_FLAGS_MASK		(SYS_OVERRIDE_IO_THROTTLE | SYS_OVERRIDE_CPU_THROTTLE)

#ifdef BSD_KERNEL_PRIVATE
void init_system_override(void);
#endif

#ifndef KERNEL
int system_override(uint64_t timeout, uint64_t flags);
#endif

__END_DECLS

#endif /*_SYS_KERN_OVERRIDES_H */

==> xnu-3247.1.106.tar.gz: xnu-3247.1.106/bsd/sys/kern_overrides.h <==
/*
 * Copyright (c) 2013 Apple Computer, Inc. All rights reserved.
 *
 * @APPLE_OSREFERENCE_LICENSE_HEADER_START@
 * 
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. The rights granted to you under the License
 * may not be used to create, or enable the creation or redistribution of,
 * unlawful or unlicensed copies of an Apple operating system, or to
 * circumvent, violate, or enable the circumvention or violation of, any
 * terms of an Apple operating system software license agreement.
 * 
 * Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this file.
 * 
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 * 
 * @APPLE_OSREFERENCE_LICENSE_HEADER_END@
 */

#ifndef _SYS_KERN_OVERRIDES_H
#define _SYS_KERN_OVERRIDES_H

#include <sys/cdefs.h>
#include <sys/param.h>
#include <sys/types.h>
#include <stdint.h>

__BEGIN_DECLS

/* System Overrides Flags */
#define SYS_OVERRIDE_DISABLE		0x0
#define SYS_OVERRIDE_IO_THROTTLE	0x1
#define SYS_OVERRIDE_CPU_THROTTLE	0x2


#define SYS_OVERRIDE_FLAGS_MASK		(SYS_OVERRIDE_DISABLE | SYS_OVERRIDE_IO_THROTTLE | SYS_OVERRIDE_CPU_THROTTLE)

#ifdef BSD_KERNEL_PRIVATE
void init_system_override(void);
#endif

#ifndef KERNEL
int system_override(uint64_t timeout, uint64_t flags);
#endif

__END_DECLS

#endif /*_SYS_KERN_OVERRIDES_H */
